You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@avro.apache.org by "Doug Cutting (JIRA)" <ji...@apache.org> on 2010/01/22 01:34:54 UTC
[jira] Commented: (AVRO-354) Performance improvement to
BinaryDecoder.readInt()
[ https://issues.apache.org/jira/browse/AVRO-354?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=12803557#action_12803557 ]
Doug Cutting commented on AVRO-354:
-----------------------------------
I do not see consistent improvements in the ReadInt benchmark, but I do see consistent, significant improvement in the NestedRecordTest. This is after applying AVRO-355. Perhaps the shorter call stack causes the integer version to be inlined in NestedRecordTest somewhere where it wasn't before?
> Performance improvement to BinaryDecoder.readInt()
> --------------------------------------------------
>
> Key: AVRO-354
> URL: https://issues.apache.org/jira/browse/AVRO-354
> Project: Avro
> Issue Type: Improvement
> Components: java
> Affects Versions: 1.3.0
> Environment: koliver@koliver-ws4:~$ uname -a
> Linux koliver-ws4 2.6.24-26-generic #1 SMP Tue Dec 1 17:55:03 UTC 2009 x86_64 GNU/Linux
> Reporter: Kevin Oliver
> Priority: Minor
> Attachments: AVRO-354-results.csv, AVRO-354.patch
>
>
> Able to get a 3-7% improvement on Perf -i by creating a specialized version of BinaryDecoder.readInt() that uses the same code as readLong() but uses ints instead of long for all its math and bit arithmetic.
> The performance improvement is larger on a 32-bit VM (around 7%) than on a 64-bit VM (around 3%).
--
This message is automatically generated by JIRA.
-
You can reply to this email to add a comment to the issue online.